@@ -1,6 +1,9 @@
 import asyncio
+import builtins
 import os
+import pydoc
 import sys
+import types
 from asyncio import Future, ensure_future
 from datetime import datetime
 from functools import partial
@@ -31,10 +34,16 @@ from prompt_toolkit.output.color_depth import ColorDepth
 from prompt_toolkit.search import start_search
 from prompt_toolkit.shortcuts import clear, message_dialog
 from prompt_toolkit.styles import Style
-from prompt_toolkit.widgets import Dialog, MenuContainer, MenuItem, SearchToolbar, TextArea
+from prompt_toolkit.widgets import (
+    Dialog,
+    MenuContainer,
+    MenuItem,
+    SearchToolbar,
+    TextArea,
+)
 from prompt_toolkit.widgets.base import Border, Button, Label
 
-from quickpython import __version__
+from quickpython import __version__, extensions
 
 ABOUT_MESSAGE = f"""QuickPython version {__version__}
 
@@ -43,6 +52,7 @@ Simultanously distributed to the US and Canada.
 And you know, the rest of the world.
 
 A productive parody.
+Made in Seattle.
 """
 
 kb = KeyBindings()
@@ -194,7 +204,7 @@ def open_file(event=None):
 
         if filename is not None:
             current_file = Path(filename).resolve()
-            isort_config = isort.Config(settings_path=current_file)
+            isort_config = isort.Config(settings_path=current_file.parent)
             black_config_file = black.find_pyproject_toml((current_file,))
             if black_config_file:
                 black_config = black.parse_pyproject_toml(black_config_file)
@@ -228,7 +238,7 @@ def save_as_file():
 
         if filename is not None:
             current_file = Path(filename).resolve()
-            isort_config = isort.Config(settings_path=current_file)
+            isort_config = isort.Config(settings_path=current_file.parent)
             black_config_file = black.find_pyproject_toml((current_file,))
             if black_config_file:
                 black_config = black.parse_pyproject_toml(black_config_file)
@@ -250,7 +260,9 @@ def black_format_code(contents: str) -> str:
     """Formats the given import section using black."""
     try:
         immediate.buffer.text = ""
-        return black.format_file_contents(contents, fast=True, mode=black.FileMode(**black_config))
+        return black.format_file_contents(
+            contents, fast=True, mode=black.FileMode(**black_config)
+        )
     except black.NothingChanged:
         return contents
     except Exception as error:
@@ -258,7 +270,7 @@ def black_format_code(contents: str) -> str:
         return contents
 
 
-def new():
+def new(content=""):
     """Creates a new file buffer."""
     global current_file
     global isort_config
@@ -267,7 +279,7 @@ def new():
     current_file = None
     isort_config = default_isort_config
     black_config = default_black_config
-    code.buffer.text = ""
+    code.buffer.text = content
     open_file_frame.title = "Untitled"
     feedback("")
 
@@ -292,7 +304,11 @@ def indent(event):
 def enter(event):
     buffer = event.app.current_buffer
     buffer.insert_text("\n")
-    if current_file and ".py" not in current_file.suffixes and ".pyi" not in current_file.suffixes:
+    if (
+        current_file
+        and ".py" not in current_file.suffixes
+        and ".pyi" not in current_file.suffixes
+    ):
         return
 
     old_cursor_position = buffer.cursor_position
@@ -325,7 +341,13 @@ def save_file(event=None):
 async def _run_buffer(debug: bool = False):
     buffer_filename = f"{current_file or 'buffer'}.qpython"
     with open(buffer_filename, "w") as buffer_file:
-        buffer_file.write(app.current_buffer.text)
+        user_code = app.current_buffer.text
+        if not user_code.endswith("\n"):
+            user_code += "\n"
+        with_qpython_injected = isort.code(
+            user_code, add_imports=["import quickpython.extensions"]
+        )
+        buffer_file.write(isort_format_code(with_qpython_injected))
         if debug:
             buffer_file.write("breakpoint()")
 
@@ -591,8 +613,8 @@ def goto(event=None):
         except ValueError:
             feedback("Invalid line number")
         else:
-            code.buffer.cursor_position = code.buffer.document.translate_row_col_to_index(
-                line_number - 1, 0
+            code.buffer.cursor_position = (
+                code.buffer.document.translate_row_col_to_index(line_number - 1, 0)
             )
 
     ensure_future(coroutine())
@@ -600,8 +622,12 @@ def goto(event=None):
 
 def replace_text():
     async def coroutine():
-        to_replace_dialog = TextInputDialog(title="Text to Replace", label_text="original:")
-        replacement_dialog = TextInputDialog(title="Replace With", label_text="replacement:")
+        to_replace_dialog = TextInputDialog(
+            title="Text to Replace", label_text="original:"
+        )
+        replacement_dialog = TextInputDialog(
+            title="Replace With", label_text="replacement:"
+        )
 
         to_replace = await show_dialog_as_float(to_replace_dialog)
         if to_replace is None:
@@ -611,7 +637,9 @@ def replace_text():
         if replacement is None:
             return
 
-        code.buffer.text = format_code(code.buffer.text.replace(to_replace, replacement))
+        code.buffer.text = format_code(
+            code.buffer.text.replace(to_replace, replacement)
+        )
 
     ensure_future(coroutine())
 
@@ -678,7 +706,9 @@ class {class_name}:
 '''
         )
         code.buffer.text = isort.code(
-            code.buffer.text, add_imports=["from dataclasses import dataclass"], float_to_top=True
+            code.buffer.text,
+            add_imports=["from dataclasses import dataclass"],
+            float_to_top=True,
         )
         code.buffer.text = format_code(code.buffer.text)
 
@@ -752,10 +782,33 @@ def search(event=None):
 def search_next(event=None):
     search_state = app.current_search_state
 
-    cursor_position = code.buffer.get_search_position(search_state, include_current_position=False)
+    cursor_position = code.buffer.get_search_position(
+        search_state, include_current_position=False
+    )
     code.buffer.cursor_position = cursor_position
 
 
+def example(game_name: str):
+    import inspect
+
+    from quickpython import examples
+
+    def expand_example():
+        new(inspect.getsource(getattr(examples, game_name)))
+
+    return expand_example
+
+
+def built_in_functions():
+    docs = [
+        pydoc.render_doc(builtin, renderer=pydoc.plaintext).split("\n", 1)[1]
+        for builtin_name, builtin in vars(builtins).items()
+        if type(builtin) in (types.FunctionType, types.BuiltinFunctionType)
+        and not builtin_name.startswith("_")
+    ]
+    new("\n".join(docs))
+
+
 QLabel = partial(Label, dont_extend_width=True)
 SPACE = QLabel(" ")
 
@@ -831,11 +884,32 @@ root_container = MenuContainer(
         ),
         MenuItem(
             " Run ",
-            children=[MenuItem("Start (F5)", handler=run_buffer), MenuItem("Debug", handler=debug)],
+            children=[
+                MenuItem("Start (F5)", handler=run_buffer),
+                MenuItem("Debug", handler=debug),
+            ],
+        ),
+        MenuItem(
+            " Examples ",
+            children=[
+                MenuItem("Connect", handler=example("connect")),
+                MenuItem("Eight Puzzle", handler=example("eightpuzzle")),
+                MenuItem("Hang Man", handler=example("hangman")),
+                MenuItem("Memory", handler=example("memory")),
+                MenuItem("Minesweeper", handler=example("minesweeper")),
+                MenuItem("Simon", handler=example("simon")),
+                MenuItem("Tic Tac Toe", handler=example("tictactoe")),
+                MenuItem("Towers", handler=example("towers")),
+                MenuItem("Zig Zag", handler=example("zigzag")),
+                MenuItem("Uno", handler=example("uno")),
+            ],
         ),
         MenuItem(
             " Help ",
-            children=[MenuItem("About", handler=about)],
+            children=[
+                MenuItem("About", handler=about),
+                MenuItem("Built-in Functions", handler=built_in_functions),
+            ],
         ),
     ],
     floats=[
@@ -870,7 +944,7 @@ def start(argv=None):
         sys.exit("Usage: qpython [filename]")
     elif len(sys.argv) == 2:
         current_file = Path(sys.argv[1]).resolve()
-        isort_config = isort.Config(settings_path=current_file)
+        isort_config = isort.Config(settings_path=current_file.parent)
         open_file_frame.title = current_file.name
         if current_file.exists():
             with current_file.open(encoding="utf8") as open_file:
