@@ -4,10 +4,12 @@ from subprocess import run
 
 
 def beep():
+    """Makes a beep sound."""
     print("\a", end="")
 
 
 def cls():
+    """Clears the screen."""
     if platform.system().lower() == "windows":
         run("cls")
     else:
@@ -15,6 +17,9 @@ def cls():
 
 
 def main(function):
+    """A decorator that causes the decorated function to be started
+    if ran directly but not if imported.
+    """
     caller = inspect.stack()[1]
     module = inspect.getmodule(caller[0])
     if module.__name__ == "__main__":
